{% include "django/forms/widgets/text.html" %}
{# FIXME make this generic? #}

<a href="#" class="button" title="Generate new" id="id_external_token_generate">
    <span class="reset-dashboard-link-icon ml-1"><i class="fas fa-redo-alt"></i></span>
</a>
